@@ -19,18 +19,14 @@ logger = logging.getLogger(__name__)
 class SnapshotConnector:
 
     @dataclass
-    class SnapshotConnectorConfig:
-        server_name: str
+    class Context(HttpServerConnector.Context):
+        project_name: str
 
-    @dataclass
-    class Config(HttpServerConnector.Config, SnapshotConnectorConfig):
-        pass
-
-    Context = HttpServerConnector.Context
+    Config = HttpServerConnector.Config
 
     def __init__(self, config: Config, context: Context):
-        self._config = config
-        self._context = context
+        self.config = config
+        self.context = context
         self._connector = HttpServerConnector(config, context)
 
     async def get_snapshot(self, stream_url: str, snapshot_timeout_s: Optional[int] = None) -> bytes:
@@ -41,4 +37,4 @@ class SnapshotConnector:
         return await self._connector.get("/snapshot/get", args, headers=self._get_auth_header())
 
     def _get_auth_header(self) -> dict[str, str]:
-        return {"server_name": self._config.server_name}
+        return {"server_name": self.context.project_name}
